aboutsummaryrefslogtreecommitdiff
path: root/gst/gstchildproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'gst/gstchildproxy.h')
-rw-r--r--gst/gstchildproxy.h72
1 files changed, 43 insertions, 29 deletions
diff --git a/gst/gstchildproxy.h b/gst/gstchildproxy.h
index ebb2d14..94e2011 100644
--- a/gst/gstchildproxy.h
+++ b/gst/gstchildproxy.h
@@ -28,10 +28,10 @@
G_BEGIN_DECLS
-#define GST_TYPE_CHILD_PROXY (gst_child_proxy_get_type ())
-#define GST_CHILD_PROXY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_CHILD_PROXY, GstChildProxy))
-#define GST_IS_CHILD_PROXY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_CHILD_PROXY))
-#define GST_CHILD_PROXY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GST_TYPE_CHILD_PROXY, GstChildProxyInterface))
+#define GST_TYPE_CHILD_PROXY (gst_child_proxy_get_type ())
+#define GST_CHILD_PROXY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_CHILD_PROXY, GstChildProxy))
+#define GST_IS_CHILD_PROXY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_CHILD_PROXY))
+#define GST_CHILD_PROXY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GST_TYPE_CHILD_PROXY, GstChildProxyInterface))
/**
* GstChildProxy:
@@ -44,7 +44,8 @@ typedef struct _GstChildProxyInterface GstChildProxyInterface;
/**
* GstChildProxyInterface:
* @parent: parent interface type.
* @get_child_by_index: virtual method to fetch the child
* @get_children_count: virtual method to get the children count
*
* #GstChildProxy interface.
@@ -54,37 +55,50 @@ struct _GstChildProxyInterface
GTypeInterface parent;
/* methods */
- GstObject *(*get_child_by_index) (GstChildProxy * parent, guint index);
- guint (*get_children_count) (GstChildProxy * parent);
+ GObject * (*get_child_by_name) (GstChildProxy * parent, const gchar * name);
+ GObject * (*get_child_by_index) (GstChildProxy * parent, guint index);
+ guint (*get_children_count) (GstChildProxy * parent);
/*< private >*/
/* signals */
- void (*child_added) (GstChildProxy * parent, GstObject * child);
- void (*child_removed) (GstChildProxy * parent, GstObject * child);
+ void (*child_added) (GstChildProxy * parent, GObject * child);
+ void (*child_removed) (GstChildProxy * parent, GObject * child);
/*< private >*/
gpointer _gst_reserved[GST_PADDING];
};
-GType gst_child_proxy_get_type (void);
-
-GstObject *gst_child_proxy_get_child_by_name (GstChildProxy * parent, const gchar * name);
-GstObject *gst_child_proxy_get_child_by_index (GstChildProxy * parent, guint index);
-guint gst_child_proxy_get_children_count (GstChildProxy * parent);
-
-gboolean gst_child_proxy_lookup (GstObject *object, const gchar *name,
- GstObject **target, GParamSpec **pspec);
-void gst_child_proxy_get_property (GstObject * object, const gchar *name, GValue *value);
-void gst_child_proxy_get_valist (GstObject * object,
- const gchar * first_property_name, va_list var_args);
-void gst_child_proxy_get (GstObject * object, const gchar * first_property_name,
- ...) G_GNUC_NULL_TERMINATED;
-void gst_child_proxy_set_property (GstObject * object, const gchar *name, const GValue *value);
-void gst_child_proxy_set_valist (GstObject* object,
- const gchar * first_property_name, va_list var_args);
-void gst_child_proxy_set (GstObject * object, const gchar * first_property_name,
- ...) G_GNUC_NULL_TERMINATED;
-void gst_child_proxy_child_added (GstObject * object, GstObject * child);
-void gst_child_proxy_child_removed (GstObject * object, GstObject * child);
+GType gst_child_proxy_get_type (void);
+
+GObject * gst_child_proxy_get_child_by_name (GstChildProxy * parent, const gchar * name);
+
+guint gst_child_proxy_get_children_count (GstChildProxy * parent);
+GObject * gst_child_proxy_get_child_by_index (GstChildProxy * parent, guint index);
+
+gboolean gst_child_proxy_lookup (GObject *object, const gchar *name,
+ GObject **target, GParamSpec **pspec);
+
+void gst_child_proxy_get_property (GObject * object, const gchar *name,
+ GValue *value);
+void gst_child_proxy_get_valist (GObject * object,
+ const gchar * first_property_name,
+ va_list var_args);
+void gst_child_proxy_get (GObject * object,
+ const gchar * first_property_name,
+ ...) G_GNUC_NULL_TERMINATED;
+
+void gst_child_proxy_set_property (GObject * object, const gchar *name,
+ const GValue *value);
+void gst_child_proxy_set_valist (GObject* object,
+ const gchar * first_property_name,
+ va_list var_args);
+void gst_child_proxy_set (GObject * object,
+ const gchar * first_property_name,
+ ...) G_GNUC_NULL_TERMINATED;
+
+void gst_child_proxy_child_added (GObject * object, GObject * child,
+ const gchar *name);
+void gst_child_proxy_child_removed (GObject * object, GObject * child,
+ const gchar *name);
G_END_DECLS
@@ -44,7 +44,8 @@ typedef struct _GstChildProxyInterface GstChildProxyInterface;
* GstChildProxyInterface:
* @parent: parent interface type.
- * @get_child_by_index: virtual method to fetch the child
+ * @get_child_by_name: virtual method to fetch the child by name
+ * @get_child_by_index: virtual method to fetch the child by index
* @get_children_count: virtual method to get the children count
*